@@ -3,8 +3,8 @@ extern crate rss;
 use core::str::FromStr;
 use std::collections::BTreeMap;
 use std::convert::TryFrom;
+use std::time::Duration;
 
-use chrono::Duration;
 use rss::extension::Extension;
 use rss::Item;
 #[cfg(any(feature = "parse-names", feature = "require-parse-names"))]
@@ -89,7 +89,7 @@ impl TryFrom<Item> for Torrent {
 				None => None
 			};
 			this.minimum_ratio = get_parsed_extension_value(torznab, "minimumrato")?;
-			this.minimum_seedtime = get_parsed_extension_value(torznab, "minimumseedtime")?.map(Duration::seconds);
+			this.minimum_seedtime = get_parsed_extension_value(torznab, "minimumseedtime")?.map(Duration::from_secs);
 		}
 		Ok(this)
 	}
